<?php

/*
   VSOP87C Venus - Apparent Geocentric Equatorial Ephemeris Demo 2

   Same as Demo 1, except tabulated in standard HMS and DMS format.

   This program should produce a Venus ephemeris for any given
   Year/Month from 1583 to 5999 AD on the Gregorian calendar.

   Author  : Jay Tanner
   License : Public Domain
*/

   ob_start(); // GO

// Attach essential modules.
   Include_Once('VSOP87C-Venus-hXYZ.php');
   Include_Once('VSOP87C-Earth-hXYZ.php');
   Include_Once('VSOP87C-Venus-hXYZR.php');
   Include_Once('VSOP87C-Geocentric-Venus.php');
   Include_Once('Utilities.php');

// Get current year (UTC).
   $cYear = GMDate('Y');

// Define minimum and maximum valid years.
   $MinYear = 1583; // Limited for practical reasons
   $MaxYear = 5999;

// Define the program cookie name and set it to expire in 30 days.
// This cookie can be shared by other programs in the same common
// home folder together.

   $CookieName = 'VSOP87C_Venus_Apparent_Geocentric_Equatorial_Ephemeris_Demo_2';
   $SetToExpireIn30Days = time() + 30*86400;

// --------------------------------
// Define script path and filename.

   $_AUTHOR_          = 'Jay Tanner';
   $_PROGRAM_VERSION_ = ''; $at = "&#97;&#116;"; $UTC = "&#85;&#84;&#67;";
   $_SCRIPT_PATH_     = Filter_Input(INPUT_SERVER, 'SCRIPT_FILENAME');
   $_RUN_             = Filter_Input(INPUT_POST, 'SCRIPT_NAME');

// -----------------------------------------------------------
// Define internal document page title, HTML page heading text
// and revision date

   $_INTERNAL_TITLE_  = "VSOP87 Venus Apparent Geocentric Equatorial Ephemeris Demo 2";
   $_INTERFACE_TITLE_ = "<span style='font-size:150%;'>VSOP87C Venus Apparent Geocentric Equatorial Ephemeris Demo 2</span><br><span style='font-size:100%;'>PHP Program by Jay Tanner - $cYear</span>";
   $_REVISION_DATE_   = $_PROGRAM_VERSION_ .'Revised: '. GMDate("l, F d, Y $at h:i:s A   $UTC", FileMTime($_SCRIPT_PATH_));

// Define dynamic source code download link.
   $DLLink = '';
   if (substr(Filter_Input(INPUT_SERVER, 'SCRIPT_FILENAME'), 0,3) <> 'D:/')
  {
   $DLLink = "<a href='vsop87-venus-apparent-geocentric-ephemeris-demo-2.zip'>Download PHP Source Code For This Program</a>";
   $DLLink = "<tr><td colspan='3' style='background:black;'><b>$DLLink</b></td></tr>";
  }
// --------------------------------------
// Define main TextArea text, background
// colors and HTML table row span.

   $TxColor = 'black';
   $BgColor = 'white';
   $ColSpan = 7;

// ---------------------------------------------
// Do this only if [COMPUTE] button was clicked.

   $w = Filter_Input(INPUT_POST, 'ComputeButton');

   if (!IsSet($w))

// ----------------------------------------------------
// If [COMPUTE] button was clicked and an active cookie
// exists, then restore the previous interface settings
// from it.
     {
      $w = Filter_Input(INPUT_COOKIE, $CookieName);
   if (IsSet($w))
      {
       $CookieDataString = Filter_Input(INPUT_COOKIE, $CookieName);
       list($yn,$mn) = Preg_Split("[\|]", $CookieDataString);
      }

   else

// -------------------------------------------------
// Set the initial default interface startup values.

 {
// Define defaults.
   $yn = GMDate('Y');
   $mn = GMDate('n');

// -----------------------------------
// Store interface settings in cookie.

   $CookieDataString = "$yn|$mn";
   setcookie ($CookieName, $CookieDataString, $SetToExpireIn30Days);
  }
      } // End of  if (!isset(_POST['ComputeButton']))







// --------------------------------------
// Read values of all interface arguments
// and set defaults on initial call.

   $w = Filter_Input(INPUT_POST, 'ComputeButton');
   if (isset($w))
{
   $yn = trim(Filter_Input(INPUT_POST, 'yn'));
   $mn = trim(Filter_Input(INPUT_POST, 'mn'));

// ---------------------------------
// Define defaults for empty values.

   if ($yn == '') {$yn = GMDate('Y');}
   if ($mn == '') {$mn = GMDate('n');}

// ------------------------------------
// Store interface arguments in cookie.

   $CookieDataString = "$yn|$mn";
   SetCookie ($CookieName, $CookieDataString, $SetToExpireIn30Days);
}





// --------------------------------------------------
// Initialize error detection flag and error message.

   $ErrorFlag = FALSE; // Default = No error yet.
   $ErrorMssg = '';    // Default = Empty string.

// ------------------------------------------------
// CODE TO CHECK FOR INVALID ARGUMENTS CAN GO HERE.
// If error detected, set $ErrorFlag = TRUE and
// define error message text.




// -------------------------------------
// Check if error detected above (TRUE).

if ($ErrorFlag === TRUE)
 {
  $TxColor = 'white';
  $BgColor = '#CC0000';
  $TextArea2Text = '';

  $TextArea1Text =
"=== ERROR ====================================================================

$ErrorMssg";
 }

else

// ===================--================================
// Begin computations below if no errors detected above.

  {
// -----------------------------------------
// Format the interface values for neatness.

   $n = $mn; //   $mn = SPrintF("%02d", $mn);

// ------------------------------------------------
// Compute the Julian Day Number for the given date
// according to the default Gregorian calendar.

   $JDNum = GregorianToJD(IntVal($mn), 1, IntVal($yn));
   $JGCal = 'Gregorian';
   $JG = 'G';

// --------------------------------------------
// Compute full Julian Date value for the given
// date at 00:00:00 TT.

   $JDTT = SPrintF("%16.8f", $JDNum - 0.5);

// ----------------------------------------------------------
// Compute Delta T estimate for middle of month
// from the NASA polynomial expressions.

   $DeltaTSec = NASA_Delta_T_Poly($JDTT+15);
   $DeltaTHrs = NASA_Delta_T_Poly($JDTT+15)/3600;
   $DeltaTHMS = Hours_to_HMS($DeltaTHrs, 0, '+', ':');

// -----------------------------------------------------
// Compute the Julian Day Number for beginning of the
// given year/month according to the Gregorian calendar.
//
// JDNum1 = JD Number of first day of given month.
// JDNum0 = JD Number of last day of previous month.
// mDays  = Days in given month.
// mName  = Full text of English month name.
// JGCal  = Calendar mode = 'Gregorian' = (FIXED DEFAULT).

   $JDNum0 = GregorianToJD(IntVal($mn), 1, IntVal($yn))-1;
   $JDNum1 = $JDNum0 + 1;
   $mDays  = Cal_Days_In_Month(CAL_GREGORIAN, IntVal($mn), IntVal($yn));
   $mName  = JDMonthName($JDNum1, CAL_MONTH_GREGORIAN_LONG);
   $JGCal  = 'Gregorian';

// ------------------------------------------
// Compute the apparent geocentric equatorial
// ephemeris table for the planet Venus at
// 00:00:00 TT on each date of the given
// month.

   $EphemTableBody = '';

   for ($day=1;   $day <= $mDays;   $day++)
{
// ----------------------------------------------
// Compute Julian Date for 00h TT on date.

   $JDTT = $JDNum0 - 0.5 + $day;

// -----------------------------------------------------
// Compute current Venus ephemeris line for Julian Date.

   $GeoVenusStats = Geocentric_Venus($JDTT);

// --------------------------------------------------
// Extract returned apparent geocentric coordinates
// and place them into their corresponding variables.

   list
  (
   $RAHrs,
   $DeclDeg,
   $DistAU,
   $AngDiamDeg,
   $VisMag,
   $PhAngDeg,
   $IllumFrac,
   $EclLonDeg,
   $EclLatDeg
  ) = Preg_Split("[ ]", $GeoVenusStats);

// ---------------------------------------
// Do some formatting for output neatness.

   $dd           = SPrintF("% 2d", $day);
   $JDTT         = SPrintF("%16.8f", $JDTT);
   $RAHMS        = Hours_to_HMS($RAHrs,   2, ''  ,'h');
   $RADeg        = SPrintF(" %14.10f", 15*$RAHrs);
   $RADMS        = Deg_to_DMS(15*$RAHrs, 2, '', 'd');
   $RAHrs        = SPrintF(" %13.10f", $RAHrs);

   $DeclDMS      = trim(Deg_to_DMS($DeclDeg, 2, '+' ,'d'));
   $DeclDMS      = substr('                   '.$DeclDMS, -19);


   $DistMkm      = SPrintF("% 10.6f", $DistAU * 149.597870691);
   $DistMmi      = SPrintF("% 10.6f", $DistAU * 149597870.691/1609344);
   $DistAU       = SPrintF("%1.10f", $DistAU);

   $w            = Deg_to_DMS(trim($AngDiamDeg), 2, '' ,'d');
   $w            = substr($w, 9, StrLen($w));
   $AngDiamDMS   = Str_Replace("00' ",'', $w);

   $PhAngDeg     = SPrintF("%1.3f", $PhAngDeg);
   $IllumFracPct = SPrintF("%1.3f", 100*$IllumFrac);
   $VisMag       = SPrintF("%+1.2f", $VisMag);
   $EclLonDMS    = trim(Deg_to_DMS(trim($EclLonDeg), 2, ''  ,'d'));
   $EclLatDMS    = trim(Deg_to_DMS(trim($EclLatDeg), 2, '+' ,'d'));

// Append current line to ephemeris table.
   $EphemTableBody .= "$dd  $RAHMS  $DeclDMS  $DistAU  $VisMag  $AngDiamDMS\n";
}
   $EphemTableBody = RTrim($EphemTableBody);





// Construct output geocentric Venus ephemeris text block.
   $ApparentVenusCoords = "$EphemTableBody";



// ------------------------------
// Construct output text block 1.

   $TextArea1Text =
"
=================================================================
   VSOP87C VENUS APPARENT GEOCENTRIC EQUATORIAL EPHEMERIS DEMO
            Valid For Gregorian Years 1583 AD to 5999 AD


=================================================================
VENUS
Apparent Geocentric Equatorial Ephemeris  For 00h TT on Each Date

Year  : $yn ($JGCal Calendar)
Month : $mName 1 to $mDays

=================================================================
Day      R.A.         Declination      Dist AU     V Mag  A Diam
=== ==============  ===============  ============  =====  =======
$EphemTableBody
=================================================================

";
  }



// TextArea2.
   $TextArea2Text =
"
SOME GENERAL INFORMATION ABOUT THIS VSOP87 VENUS EPHEMERIS DEMO

The purpose of this program is to compute an apparent geocentric
equatorial Venus ephemeris for any Gregorian calendar date within
the ephemeris span from 1583 to 5999 AD based on the VSOP87 theory.

-------
CAVEAT:
Be cautious when entering the year/month values. This program is only
a simplified demo and does NOT do extensive error checking for invalid
arguments.  Valid input arguments should return valid results.  Whenever
possible, compare against known check values or against another source
of similar VSOP87C computations for consistency.

----------------
TIME SCALE USED:
The program uses the system clock for the time (UTC). However, the actual
time scale used is the TT scale.  Without any Delta T adjustment, UTC is
being treated as equivalent to TT.

---------------------------------------------------------------------------
SOURCE CODE:
There is a link below to the complete PHP source code for this program.
";






// Determine the number of text rows to use in the output TextAreas.
   $TextArea1Rows = 2 + substr_count($TextArea1Text, "\n");
   $TextArea2Rows = 2 + substr_count($TextArea2Text, "\n");



print <<< _HTML

<!DOCTYPE HTML>

<head>

<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="content-type" content="text/html; charset=UTF-8">
<meta name="description" content="VSOP87 Venus Apparent Geocentric Equatorial Ephemeris Demo">
<meta name="keywords" content="VSOP87,VSOP87 Venus,VSOP87 Earth,VSOP87 Demo">
<meta name="author" content="Jay Tanner - https://www.PHPScienceLabs.com">
<meta http-equiv="pragma"  content="no-cache">
<meta http-equiv="expires" content="-1">
<meta name="robots"    content="index,follow">
<meta name="googlebot" content="index,follow">


<style>
 BODY
{color:silver; background-color:black;  font-family:Verdana; font-size:100%}

 TABLE
{font-size:12px; border: 1px solid black;}

 TD
{color:black; background-color:white; line-height:200%; font-size:12px;
padding:6px; text-align:center;}

 DIV
{
 color:black; background-color:white; font-family:Verdana; font-size:110%;
 text-align:justify; padding:4px;
}

 PRE
{color:black; background-color:white; font-family:monospace;
 font-size:150%; font-weight:bold; text-align:left; padding:4px;}

 CODE
{font-family:monospace; font-size:150%; font-weight:normal;}

 TEXTAREA
{
 color:black; background:white; font-family:monospace; font-size:150%;
 font-weight:bold; border-radius: 8px; border:1px solid black; padding:4px;
 white-space:pre;
}

 INPUT[type="text"]::-ms-clear {width:0; height:0;}

 INPUT[type="text"]
{
 color:black; background:white; font-size:150%; font-family:monospace;
 font-weight:bold; text-align:center; box-shadow:2px 2px 3px #666666;
 border:2px solid black; border-radius:4px;
}

 INPUT[type="text"]:focus
{
 background:white; box-shadow:2px 2px 3px #666666; font-family:monospace;
 font-size:150%; border:2px solid blue; text-align:center;
 font-weight:bold; border-radius:4px;
}

 INPUT[type="submit"]
{font-weight:bold;}

 INPUT[type="submit"]:hover
{box-shadow:2px 2px 5px #555555; font-weight:bold;}

 HR {background:black; height:2px; border:0px;}

 A:link
{
 font-size:100%; background:transparent; color:DodgerBlue; font-family:Verdana;
 font-weight:bold; text-decoration:none; line-height:175%; padding:3px;
 border:1px solid transparent;
}

 A:visited {font-size:100%; background:transparent; color:DodgerBlue;}

 A:hover
{
 font-size:100%; background:yellow; color:black; border:1px solid black;
 box-shadow:1px 1px 3px #222222;
}

 A:active  {font-size:100%; background:yellow; color:black;}

::selection      {background-color:yellow; color:black;}
::-moz-selection {background-color:yellow; color:black;}
</style>

</head>

<body>

<form name='form1' method='post' action="$_RUN_">

<table width='800' border='0' cellspacing='1' cellpadding='3'>

<tr><td colspan="$ColSpan" style='color:white; background-color:#000044; border:2px solid white; border-radius:8px 8px 0px 0px;'>$_INTERFACE_TITLE_</td></tr>


<tr><td><b>ENTER&nbsp; Year/Month &nbsp;<input name='yn'  type='text' value="$yn"  size='5' maxlength='4' title=' Year  1583  to  5999 '>
<input name='mn'  type='text' value="$mn"  size='3' maxlength='2' title=' Month  1  to  12 '></b></td></tr>




<tr><td colspan="$ColSpan" style='background-color:black;'>
<input name='ComputeButton' type='submit' value=' C O M P U T E '>
</td></tr>



<tr>
<td colspan="$ColSpan" style='color:white; background-color:black;'>
Double-Click Within Text Area to Select ALL Text<br>
<textarea name='TextArea1' style='color:$TxColor; background:$BgColor; padding:6px; border:2px solid white;' cols="81" rows="$TextArea1Rows" ReadOnly OnDblClick='this.select();' OnMouseUp='return true;'>
$TextArea1Text
</textarea></td>
</tr>



<tr>
<td colspan="$ColSpan" style='background:black;'>
<textarea name='TextArea2' style='color:black; background:white; padding:6px;' cols="81" rows="$TextArea2Rows" ReadOnly>
$TextArea2Text
</textarea></td>
</tr>


<tr><td colspan="$ColSpan" style='color:gray; background:black;'>Program by $_AUTHOR_<br>$_REVISION_DATE_</td></tr>

$DLLink

</table>
</form>

<br><br><br><br><br><br><br><br><br><br><br><br>
<br><br><br><br><br><br><br><br><br><br><br><br>

</body>




_HTML;


?>


